@@ -1,12 +1,12 @@
 #' Function to match pixels to their corresponding polygon
-#' 
-#' From the covariate data and polygon data, the function matches the polygon id between the two to find 
+#'
+#' From the covariate data and polygon data, the function matches the polygon id between the two to find
 #' which pixels from the covariate data are contained in each of the polygons.
-#' 
-#' Takes a data.frame containing the covariate data with a polygon id column and one column for each covariate, 
-#' and another data.frame containing polygon data with a polygon id, response and sample size column (as returned 
+#'
+#' Takes a data.frame containing the covariate data with a polygon id column and one column for each covariate,
+#' and another data.frame containing polygon data with a polygon id, response and sample size column (as returned
 #' by \code{getPolygonData} function).
-#' 
+#'
 #' Returns a matrix with two columns and one row for each polygon. The first column is the index of the first row in
 #' covariate data that corresponds to that polygon, the second column is the index of the last row in
 #' covariate data that corresponds to that polygon.
@@ -14,7 +14,7 @@
 #' @param covariates data.frame with each covariate as a column an and id column.
 #' @param polygon_data data.frame with polygon id and response data.
 #' @param id_var string with the name of the column in the covariate data.frame containing the polygon id.
-#' 
+#'
 #' @return A matrix with two columns and one row for each polygon. The first column is the index of the first row in
 #' covariate data that corresponds to that polygon, the second column is the index of the last row in
 #' covariate data that corresponds to that polygon.
@@ -43,7 +43,7 @@ getStartendindex <- function(covariates, polygon_data, id_var = 'area_id') {
 
   startendindex <- do.call(rbind, startendindex)
 
-  whichindices <- match(polygon_data$area_id, unique(covariates[, id_var]))
+  whichindices <- terra::match(polygon_data$area_id, unique(covariates[, id_var]))
 
   # c++ is zero indexed.
   startendindex <- startendindex[whichindices, ] - 1L
